Python Module Index — GuessIt 0.7.2.dev0 documentation

### Navigation

- index
- modules |
- GuessIt 0.7.2.dev0 documentation »

# Python Module Index

g

| g |
| `guessit` |
| `guessit.guess` |
| `guessit.matcher` |
| `guessit.matchtree` |

GuessIt is a python library that tries to extract as much information as possible from a file.

### Related Topics

- Documentation overview

### Quick search

Enter search terms or a module, class or function name.

© Copyright 2014 Nicolas Wack.